summaryrefslogtreecommitdiff
path: root/src/gui/gui.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/gui.h')
-rw-r--r--src/gui/gui.h12
1 files changed, 11 insertions, 1 deletions
diff --git a/src/gui/gui.h b/src/gui/gui.h
index af83ccac..b6b134e1 100644
--- a/src/gui/gui.h
+++ b/src/gui/gui.h
@@ -105,8 +105,9 @@ extern ALFONT_FONT *gui_font;
extern gcn::Container* guiTop; // The top container
extern gcn::AllegroGraphics* guiGraphics; // Graphics driver
+extern gcn::ImageFont* guiFont; // The gui font
-/* Definition of the callback function prototypes */
+// Definition of the callback function prototypes
typedef int (*gui_buttonCallback)(int id);
typedef char *(*getfuncptr)(int, int *);
@@ -116,6 +117,14 @@ int gui_update(DIALOG_PLAYER *player);
int gui_load_skin(const char* skinname);
void gui_shutdown(void);
+// Helper procedures used for GUI drawing
+gcn::Rectangle getScreenDimension(gcn::Widget *widget);
+void draw_skinned_rect(BITMAP*dst, LexSkinnedRect *skin,
+ int x, int y, int w, int h);
+int gui_text(BITMAP *bmp, AL_CONST char *s,
+ int x, int y, int color, int centre);
+
+// Old Allegro GUI procs
int tmw_button_proc(int msg, DIALOG *d, int c);
int tmw_slider_proc(int msg, DIALOG *d, int c);
int tmw_check_proc(int msg, DIALOG *d, int c);
@@ -134,4 +143,5 @@ int tmw_plus_proc(int msg, DIALOG *d, int c);
void ok(const char *title, const char *message);
unsigned int yes_no(const char *title, const char *message);
+
#endif